.. AIPY documentation master file, created by
   sphinx-quickstart on Fri Mar  4 13:47:32 2011.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to AIPY's documentation!
================================
AIPY (Astronomical Interferometry in PYthon) collects together tools for radio astronomical interferometry. In addition to pure-python phasing, calibration, imaging, and deconvolution code, this package includes interfaces to `MIRIAD <http://carma.astro.umd.edu/miriad/>`_ (a Fortran interferometry package) and `HEALPix <http://healpix.jpl.nasa.gov/>`_ (a package for representing spherical data sets), and some math/fitting routines from SciPy.

Contents
========

Installation
------------
.. toctree::
   :maxdepth: 2

   install

General Utililties
------------------
.. toctree::
   :maxdepth: 2

   const
   interp
   coord
   src

Interferometry Utilities
------------------------
.. toctree::
   :maxdepth: 2

   phs
   amp
   fit
   rfi

Imaging
-------
.. toctree::
   :maxdepth: 2

   img
   deconv
   map

Miscellaneous
-------------
.. toctree::
   :maxdepth: 2

   miriad
   healpix
   scripting

Included Scripts
----------------
.. toctree::
   :maxdepth: 2

   scripts

Tutorial
========
.. toctree::
   :maxdepth: 2

   tutorial

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

